<?php

namespace TriNetAssess\Tests;

use TriNetAssess\Company;
use TriNetAssess\App;
use TriNetAssess\Bundle;

class CompanyTest extends \PHPUnit_Framework_TestCase
{
    protected $appA;
    protected $appB;
    protected $appC;
    protected $bundleX;

    public function setUp() {
        $this->appA = new App('aA', 'App A', 100);
        $this->appB = new App('aB', 'App B', 200);
        $this->appC = new App('aC', 'App C', 300);
        $this->bundleX = new Bundle('bX', 'Bundle X', [$this->appB, $this->appC]);
    }

    public function testConstructor() {
        $company = new Company('cA', 'Company A', [$this->appA, $this->appB]);
        $this->assertEquals($company->getApps(), [$this->appA, $this->appB]);
    }
     
    public function testConstructor_duplicates() {
        $company = new Company('cA', 'Company A', [$this->appA, $this->appB, $this->appA, $this->appC, $this->appB]);
        $this->assertEquals($company->getApps(), [$this->appA, $this->appB, $this->appC]);
    }
    
    public function testAddApp() {
        $company = new Company('cA', 'Company A', [$this->appA, $this->appB]);
        $company->addApp($this->appC);
        
        $this->assertEquals($company->getApps(), [$this->appA, $this->appB, $this->appC]);
    }
    
    public function testAddApp_duplicate() {
        $company = new Company('cA', 'Company A', [$this->appA, $this->appB]);
        $company->addApp($this->appB);
        
        $this->assertEquals($company->getApps(), [$this->appA, $this->appB]);
    }
    
    public function testAddBundle() {
        $company = new Company('cA', 'Company A', [$this->appA]);
        $company->addBundle($this->bundleX);
        
        $this->assertEquals($company->getApps(), [$this->appA, $this->appB, $this->appC]);
    }
    
    public function testAddBundle_duplicate() {
        $company = new Company('cA', 'Company A', [$this->appA, $this->appB]);
        $company->addBundle($this->bundleX);
        
        $this->assertEquals($company->getApps(), [$this->appA, $this->appB, $this->appC]);
    }
    
    public function testMonthlyCostCents() {
        $company = new Company('cA', 'Company A', [$this->appA, $this->appB, $this->appC]);
        $this->assertEquals($company->getMonthlyCostCents(), 600);
    }
    
    public function testAnualCostCents() {
        $company = new Company('cA', 'Company A', [$this->appA, $this->appB, $this->appC]);
        $this->assertEquals($company->getAnualCostCents(), 7200);
    }
}